@@ -24,8 +24,7 @@ import functools
 import milla
 import re
 import sys
-import urllib
-import urlparse
+import warnings
 
 class Router(object):
     '''A dispatcher that maps arbitrary paths to controller callables
@@ -98,7 +97,7 @@ class Router(object):
                     for attr in functools.WRAPPER_ASSIGNMENTS:
                         try:
                             value = getattr(controller, attr)
-                        except AttributeError:
+                        except AttributeError: #pragma: no cover
                             pass
                         else:
                             setattr(func, attr, value)
@@ -201,7 +200,7 @@ class Router(object):
         module ``some.module``.
         '''
 
-        if isinstance(controller, basestring):
+        if not hasattr(controller, '__call__'):
             controller = self._import_controller(controller)
         self.routes.append((self._compile_template(template),
                             controller, vars))
@@ -220,24 +219,28 @@ class Generator(object):
     A common pattern is to wrap this in a stub function::
     
        url = Generator(request).generate
+
+    .. deprecated:: 0.2
+       Use :py:meth:`milla.Request.create_href` instead.
     '''
 
     def __init__(self, request, path_only=True):
         self.request = request
         self.path_only = path_only
+        warnings.warn(
+            'Use of Generator is deprecated; '
+            'use milla.Request.create_href instead',
+            DeprecationWarning,
+            stacklevel=2
+        )
 
     def generate(self, *segments, **vars):
         '''Combines segments and the application's URL into a new URL
         '''
 
         path = '/'.join(str(s) for s in segments)
-        while path.startswith('/'):
-            path = path[1:]
 
-        url = self.request.relative_url(path, to_application=True)
         if self.path_only:
-            split = urlparse.urlsplit(url)
-            url = split.path
-        if vars:
-            url += '?' + urllib.urlencode(vars)
-        return url
+            return self.request.create_href(path, **vars)
+        else:
+            return self.request.create_href_full(path, **vars)
